@@ -151,7 +151,8 @@ class EB_ALADIN(EasyBlock):
             self.log.error("Failed to remove existing file %s: %s" % (self.conf_filepath, err))
 
         mpich = 'n'
-        if self.toolchain.options['usempi'] and self.toolchain.mpi_family() in [toolchain.MPICH2, toolchain.INTELMPI]:
+        known_mpi_libs = [toolchain.MPICH2, toolchain.INTELMPI]
+        if self.toolchain.options.get('usempi', None) and self.toolchain.mpi_family() in known_mpi_libs:
             mpich = 'y'
 
         qpref = 'Please type the ABSOLUTE name of '
