@@ -52,13 +52,13 @@ class MakeCp(ConfigureMake):
         """
         Configure build if required
         """
-        if self.cfg['with_configure']:
+        if self.cfg.get('with_configure', False):
             return super(MakeCp, self).configure_step(cmd_prefix=cmd_prefix)
 
     def install_step(self):
         """Install by copying specified files and directories."""
         try:
-            for fil in self.cfg["files_to_copy"]:
+            for fil in self.cfg.get('files_to_copy', {}):
                 if isinstance(fil, tuple):
                     # ([src1, src2], targetdir)
                     if len(fil) == 2 and isinstance(fil[0], list) and isinstance(fil[1], basestring):
