@@ -78,11 +78,9 @@ class PythonPackage(ExtensionEasyBlock):
         self.sitecfglibdir = None
         self.sitecfgincdir = None
         self.testinstall = False
-        self.installopts = ''
         self.testcmd = None
         self.unpack_options = ''
 
-        self.python = None
         self.pylibdir = None
 
         # make sure there's no site.cfg in $HOME, because setup.py will find it and use it
@@ -95,7 +93,8 @@ class PythonPackage(ExtensionEasyBlock):
     def prepare_step(self):
         """Prepare easyblock by determining Python site lib dir."""
         super(PythonPackage, self).prepare_step()
-        self.pylibdir = det_pylibdir()
+        if not self.pylibdir:
+            self.pylibdir = det_pylibdir()
 
     def prerun(self):
         """Prepare extension by determining Python site lib dir."""
@@ -105,8 +104,7 @@ class PythonPackage(ExtensionEasyBlock):
     def configure_step(self):
         """Configure Python package build."""
 
-        self.python = get_software_root('Python')
-        if not self.python:
+        if not self.pylibdir:
             self.log.error('Python module not loaded.')
         self.log.debug("Python library dir: %s" % self.pylibdir)
 
@@ -163,7 +161,8 @@ class PythonPackage(ExtensionEasyBlock):
                 except OSError, err:
                     self.log.error("Failed to create test install dir: %s" % err)
 
-                cmd = "python setup.py install --prefix=%s %s" % (testinstalldir, self.installopts)
+                tup = (self.cfg['preinstallopts'], testinstalldir, self.cfg['installopts'])
+                cmd = "%s python setup.py install --prefix=%s %s" % tup
                 run_cmd(cmd, log_all=True, simple=True)
 
                 run_cmd("python -c 'import sys; print(sys.path)'")  # print Python search path (debug)
@@ -191,7 +190,8 @@ class PythonPackage(ExtensionEasyBlock):
         env.setvar('PYTHONPATH', ":".join([x for x in [abs_pylibdir, pythonpath] if x is not None]))
 
         # actually install Python package
-        cmd = "python setup.py install --prefix=%s %s" % (self.installdir, self.cfg['installopts'])
+        tup = (self.cfg['preinstallopts'], self.installdir, self.cfg['installopts'])
+        cmd = "%s python setup.py install --prefix=%s %s" % tup
         run_cmd(cmd, log_all=True, simple=True)
 
         # restore PYTHONPATH if it was set
