@@ -103,11 +103,14 @@ class EB_Python(ConfigureMake):
                 abiflags = abiflags.strip()
 
         custom_paths = {
-                        'files': ["bin/%s" % pyver, "lib/lib%s%s.so" % (pyver, abiflags)],
-                        'dirs': ["include/%s%s" % (pyver, abiflags), "lib/%s" % pyver]
-                       }
+            'files': ["bin/%s" % pyver, "lib/lib%s%s.so" % (pyver, abiflags)],
+            'dirs': ["include/%s%s" % (pyver, abiflags), "lib/%s" % pyver]
+        }
+
+        # make sure that ctypes are actually working, this is needed for a lot of dependencies
+        custom_commands = [('python', '-c "import _ctypes"')]
 
         # cleanup
         self.clean_up_fake_module(fake_mod_data)
 
-        super(EB_Python, self).sanity_check_step(custom_paths=custom_paths)
+        super(EB_Python, self).sanity_check_step(custom_paths=custom_paths, custom_commands=custom_commands)
